@@ -1,4 +1,4 @@
-# -*- coding:utf-8 -*-
+# coding: utf-8
 """
 文件上传下载接口
 """
@@ -34,6 +34,7 @@ code_dict = {
     "128512": "连接超时",
     "128513": "读取文件失败",
     "128514": "权限不足",
+    "128515": "业务场景不存在",
 }
 
 
@@ -50,7 +51,7 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
     :param file_path: 本地文件路径，可以选择文件路径或者文件流
     :param mount_path: 服务器mount地址
     :param replace: 当文件已在服务器存在时是否强制替换，默认替换
-    :param recovery_path: 容灾路径，当文件上传非正常失败时（调用接口非正常错误码），将文件存储的本地地址
+    :param recovery_path: 容灾路径，当文件上传非正常失败时（调用接口非正常错误码），将文件存储的本地地址，此时返回的mount_path为空
     :param timeout: 超时时间，默认3秒
     :param logger: 日志对象
     :return:
@@ -59,10 +60,12 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
     try:
         logger = logger if logger else logging
         if not remote_path or not x_type or not req_url:
-            return 128502, code_dict.get("128502"), ""
+            code = 128502
+            return code, code_dict.get(str(code)), ""
         if file:
             if not filename:
-                return 128502, code_dict.get("128502"), ""
+                code = 128502
+                return code, code_dict.get(str(code)), ""
             if isinstance(file, bytes):
                 file = base64.b64decode(file)
             if isinstance(file, Iterable):
@@ -73,14 +76,17 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
             param = {'picData': (filename, file, 'application/octet-stream')}
         elif file_path:
             if not os.path.isfile(file_path):
-                return 128506, code_dict.get("128506"), ""
+                code = 128506
+                return code, code_dict.get(str(code)), ""
             try:
                 file_like_obj = open(file_path, 'rb')
             except FileNotFoundError:
-                return 128505, code_dict.get("128505"), ""
+                code = 128505
+                return code, code_dict.get(str(code)), ""
             param = {'picData': file_like_obj}
         else:
-            return 128502, code_dict.get("128502"), ""
+            code = 128502
+            return code, code_dict.get(str(code)), ""
         headers = {
             "X-File-Path": remote_path,
             "X-Type": x_type,
@@ -116,16 +122,16 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
         if (code in [128509, 128512, 1] or not code_dict.get(str(code), None)) and recovery_path:
             try:
                 if not os.path.exists(recovery_path):
-                    code, err, ret_mount_path = 128504, code_dict.get("128504"), ""
+                    return 128504, code_dict.get("128504"), ""
                 if file_path:
                     file_gen = None
                     filename = os.path.basename(file_path)
                     try:
                         file_gen = gen_file(file_path)
                     except FileNotFoundError:
-                        code, err, ret_mount_path = 128505, code_dict.get("128505"), ""
+                        return 128505, code_dict.get("128505"), ""
                     except IOError:
-                        code, err, ret_mount_path = 128513, code_dict.get("128513"), ""
+                        return 128513, code_dict.get("128513"), ""
                     except Exception as exc:
                         logger.error(traceback.format_exc())
                         raise_(Exception, exc)
@@ -136,6 +142,9 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
                 else:
                     with open(os.path.join(recovery_path, filename), 'ab') as f:
                         f.write(file)
+                code = 0
+                err = code_dict.get("0")
+                ret_mount_path = ""
             except IOError:
                 return 128510, code_dict.get("128510"), ""
             except Exception as exc:
@@ -163,17 +172,22 @@ def describe_file(remote_full_path, req_url, local_full_path=None,
     try:
         logger = logger if logger else logging
         if not remote_full_path or not req_url:
-            return 128502, code_dict.get("128502"), ""
+            code = 128502
+            return code, code_dict.get(str(code)), ""
         if recovery_full_path and not os.path.isfile(recovery_full_path):
-            return 128506, code_dict.get("128506"), ""
+            code = 128506
+            return code, code_dict.get(str(code)), ""
         if not return_file:
             if not local_full_path:
-                return 128502, code_dict.get("128502"), ""
+                code = 128502
+                return code, code_dict.get(str(code)), ""
             else:
                 if os.path.exists(local_full_path):
-                    return 128507, code_dict.get("128507"), ""
+                    code = 128507
+                    return code, code_dict.get(str(code)), ""
                 if not str(os.path.split('./demo.py')[-1]).split(".")[1]:
-                    return 128503, code_dict.get(str(128503)), ""
+                    code = 128503
+                    return code, code_dict.get(str(code)), ""
         param = {'locateFile': remote_full_path}
         resp = requests.post(url=req_url, json=param, verify=False, timeout=timeout)
         http_code = resp.status_code
@@ -185,9 +199,11 @@ def describe_file(remote_full_path, req_url, local_full_path=None,
                         with open(local_full_path, "wb") as f:
                             f.write(ret_file)
                     except IOError:
-                        return 128513, code_dict.get("128513"), ""
+                        code = 128513
+                        return code, code_dict.get(str(code)), ""
                 else:
-                    return 128507, code_dict.get("128507"), ""
+                    code = 128507
+                    return code, code_dict.get(str(code)), ""
             code = 0
             err = '操作成功'
         elif http_code == 401:
@@ -234,28 +250,34 @@ def describe_file(remote_full_path, req_url, local_full_path=None,
                                 for fc in recovery_file:
                                     f.write(fc)
                         else:
-                            code, err, ret_file = 128507, code_dict.get("128507"), ""
+                            return 128507, code_dict.get("128507"), ""
+                    code = 0
+                    err = '操作成功'
+                    if return_file:
+                        with open(local_full_path, "rb") as f:
+                            ret_file = f.read()
+                    else:
+                        ret_file = ""
                 except FileNotFoundError:
-                    code, err, ret_file = 128505, code_dict.get("128505"), ""
+                    return 128505, code_dict.get("128505"), ""
                 except IOError:
-                    code, err, ret_file = 128513, code_dict.get("128513"), ""
+                    return 128513, code_dict.get("128513"), ""
                 except Exception as exc:
                     logger.error(traceback.format_exc())
                     raise_(Exception, exc)
-            if not return_file:
-                ret_file = ""
             return code, err, ret_file
         except Exception as exc:
             logger.error(traceback.format_exc())
             raise_(Exception, exc)
 
 
-def modify_file(remote_full_path, req_url, modified_file_name, timeout=3, logger=logging):
+def modify_file(remote_full_path, req_url, modified_file_name, recovery_full_path=None, timeout=3, logger=logging):
     """
     修改文件名
     :param remote_full_path: 远程文件存储路径及完整文件名称，全地址
     :param req_url: 请求URL地址，必传
     :param modified_file_name: 修改后的文件名
+    :param recovery_full_path: 容灾目录文件，当服务器修改文件名称失败时，修改此文件名称
     :param timeout: 超时时间
     :param logger: 日志对象
     :return:
@@ -264,10 +286,15 @@ def modify_file(remote_full_path, req_url, modified_file_name, timeout=3, logger
     try:
         logger = logger if logger else logging
         if not remote_full_path or not req_url or not modified_file_name:
-            return 128502, code_dict.get("128502")
+            code = 128502
+            return code, code_dict.get(str(code))
+        if recovery_full_path and not os.path.isfile(recovery_full_path):
+            code = 128506
+            return code, code_dict.get(str(code))
         _, old_name = os.path.split(remote_full_path)
         if old_name == modified_file_name:
-            return 128507, code_dict.get("128507")
+            code = 128507
+            return code, code_dict.get(str(code))
         param = {'filePath': remote_full_path, 'fileName': modified_file_name}
         resp = requests.post(url=req_url, json=param, verify=False, timeout=timeout)
         http_code = resp.status_code
@@ -277,7 +304,6 @@ def modify_file(remote_full_path, req_url, modified_file_name, timeout=3, logger
                 body = json.loads(response)
             except Exception as exc:
                 body = response
-            print(response)
             code = body.get('code')
             err = body.get('err', '') if body.get('err', '') else code_dict.get(str(code))
         else:
@@ -292,6 +318,26 @@ def modify_file(remote_full_path, req_url, modified_file_name, timeout=3, logger
     except Exception as exc:
         logger.error(traceback.format_exc())
         raise_(Exception, exc)
+    finally:
+        try:
+            if (code in [128509, 128512, 1] or not code_dict.get(str(code), None)) and recovery_full_path:
+                try:
+                    recovery_path, recovery_name = os.path.split(recovery_full_path)
+                    if recovery_name == modified_file_name:
+                        return 128507, code_dict.get("128507")
+                    new_recovery_full = os.path.join(recovery_path, modified_file_name)
+                    os.rename(recovery_full_path, new_recovery_full)
+                    code, err = 0, code_dict.get("0")
+                except FileNotFoundError:
+                    return 128505, code_dict.get("128505")
+                except OSError:
+                    return 128507, code_dict.get("128507")
+                except Exception as exc:
+                    logger.error(traceback.format_exc())
+                    raise_(Exception, exc)
+        except Exception as exc:
+            logger.error(traceback.format_exc())
+            raise_(Exception, exc)
     return code, err
 
 
